#!/usr/bin/env python3

"""Create and email a list of new items

Author: Gem Stone-Logan
Contact Info: gemstonelogan@gmail.com
"""

import psycopg2
import xlsxwriter
import smtplib
from email.mime.multipart import MIMEMultipart
from email.mime.base import MIMEBase
from email.mime.text import MIMEText
from email.utils import formatdate
from email import encoders

#Name of Excel File
excelfile =  'WeeklyNewItem.xlsx'

# These are variables for the email that will be sent.
# Make sure to use your own library's email server (emailhost)
emailhost = 'work email server'
emailport = '25'
emailsubject = 'Weekly New Report'
emailmessage = '''***This is an automated email***


The weekly new report has been attached. Please take a look and let the Technology Librarian know if there are any questions about it.'''

# Enter your own email information
emailfrom= 'from email address'
emailto = ['first email address','second email address']


#Connecting to Sierra PostgreSQL database
try:
    conn = psycopg2.connect("dbname='iug' user='iuguser' host='localhost' port='1032' password='iugprog' sslmode='require'")
except psycopg2.Error as e:
    print ("Unable to connect to database: " + str(e))

#Opening a session and querying the database for weekly new items
cursor = conn.cursor()
cursor.execute(open("WeeklyNewItemsRev.sql","r").read())
#For now, just storing the data in a variable. We'll use it later.
rows = cursor.fetchall()
conn.close()

#Creating the Excel file for staff
workbook = xlsxwriter.Workbook(excelfile)
worksheet = workbook.add_worksheet()


#Formatting our Excel worksheet
worksheet.set_landscape()
worksheet.hide_gridlines(0)

#Formatting Cells
eformat= workbook.add_format({'text_wrap': True, 'valign': 'top'})
eformatlabel= workbook.add_format({'text_wrap': True, 'valign': 'top', 'bold': True})

# Setting the column widths
worksheet.set_column('A:A',10.29)
worksheet.set_column('B:B',6.29)
worksheet.set_column('C:C',12.71)
worksheet.set_column('D:D',16.57)
worksheet.set_column('E:E',24.71)
worksheet.set_column('F:F',11.14)
worksheet.set_column('G:G',18.47)
worksheet.set_column('H:J',4.5)

#Inserting a header
worksheet.set_header('&CWeekly New List')

# Adding column labels
worksheet.write('A1','Bib Record#', eformatlabel)
worksheet.write('B1','Location', eformatlabel)
worksheet.write('C1','Call#', eformatlabel)
worksheet.write('D1','Author', eformatlabel)
worksheet.write('E1','Title', eformatlabel)
worksheet.write('F1','Barcode', eformatlabel)
worksheet.write('G1','Series', eformatlabel)
worksheet.write('H1','Item Count', eformatlabel)
worksheet.write('I1','Order Count', eformatlabel)
worksheet.write('J1','Hold Count', eformatlabel)


# Writing the report for staff to the Excel worksheet
for rownum, row in enumerate(rows):
    worksheet.write(rownum+1,0,row[0], eformat)
    worksheet.write(rownum+1,1,row[1], eformat)
    worksheet.write(rownum+1,2,row[2], eformat)
    worksheet.write(rownum+1,3,row[3], eformat)
    worksheet.write(rownum+1,4,row[4], eformat)
    worksheet.write(rownum+1,5,row[5], eformat)
    worksheet.write(rownum+1,6,row[6], eformat)
    worksheet.write(rownum+1,7,row[7], eformat)
    worksheet.write(rownum+1,8,row[8], eformat)
    worksheet.write(rownum+1,9,row[9], eformat)

workbook.close()

#Creating the email message
msg = MIMEMultipart()
msg['From'] = emailfrom
if type(emailto) is list:
    msg['To'] = ', '.join(emailto)
else:
    msg['To'] = emailto
msg['Date'] = formatdate(localtime = True)
msg['Subject'] = emailsubject
msg.attach (MIMEText(emailmessage))
part = MIMEBase('application', "octet-stream")
part.set_payload(open(excelfile,"rb").read())
encoders.encode_base64(part)
part.add_header('Content-Disposition','attachment; filename=%s' % excelfile)
msg.attach(part)

#Sending the email message
smtp = smtplib.SMTP(emailhost, emailport)
smtp.sendmail(emailfrom, emailto, msg.as_string())
smtp.quit()
